@@ -3,11 +3,7 @@
 * pgpool: a language independent connection pool server for PostgreSQL
 * written by Tatsuo Ishii
 *
-<<<<<<< HEAD
-* Copyright (c) 2003-2019	PgPool Global Development Group
-=======
 * Copyright (c) 2003-2025	PgPool Global Development Group
->>>>>>> 4990d8bc9 (Fix possible integer overflow.)
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby
@@ -260,7 +256,7 @@ pool_read(POOL_CONNECTION * cp, void *buf, int len)
 			}
 			else
 			{
-				ereport(FRONTEND_ERROR,
+				ereport(FRONTEND_DEBUG,
 						(errmsg("unable to read data from frontend"),
 						 errdetail("socket read failed with error \"%m\"")));
 			}
@@ -285,7 +281,7 @@ pool_read(POOL_CONNECTION * cp, void *buf, int len)
 				 * if backend offers authentication method, frontend could
 				 * close connection
 				 */
-				ereport(FRONTEND_ERROR,
+				ereport(FRONTEND_DEBUG,
 						(errmsg("unable to read data from frontend"),
 						 errdetail("EOF encountered with frontend")));
 			}
@@ -777,7 +773,7 @@ pool_flush(POOL_CONNECTION * cp)
 						(errmsg("unable to flush data to frontend"),
 						 errdetail("pgpool is in replication mode, ignoring error to keep consistency among backends")));
 			else
-				ereport(FRONTEND_ERROR,
+				ereport(FRONTEND_DEBUG,
 						(errmsg("unable to flush data to frontend")));
 
 		}
